#################################################
#
# Perlモジュール用のプラグインインターフェイス
#
# ※このテキストは必ずUTF-8で記述すること
#   扱う文字列は全てUTF-8前提であるとする
#
#################################################

package Atok_plugin;

#################################################
# 宣言

use strict;
use utf8;
use Encode;
use LWP::Simple qw/get/;
use URI::Escape qw/uri_escape/;

#################################################
# 取得処理を実行する
# ・設定した候補を返すことが可能
# ・最大で100個の候補を返すことができる
# ・候補には、
#   １．表記
#   ２．コメント
#   ３．ツールチップ（確定文字列かURLジャンプ文字列）
#   を設定できる
# ・何もセットしなかった場合、処理結果は何もないと判断される
# ・引数で渡される情報に含まれる文字列は、全てUTF8フラグが付いている
# ・返す情報に含める文字列は必ずUTF8にする必要がある
#   （UTF8フラグは付いていなくても問題ない）

sub run_process
{
 my( $a_request_data ) = @_;

 my %result_data;

 my @candidate_array;

 my $a_encoded_request_data = uri_escape(encode 'eucjp', $a_request_data->{composition_string});
 my $a_response_from_hatena_web_search = decode 'eucjp', get("http://search.hatena.ne.jp/search?word=$a_encoded_request_data");
 print STDERR encode 'shiftjis', $a_response_from_hatena_web_search;
 my($a_number_of_found_pages) = $a_response_from_hatena_web_search =~ m{ウェブ全体から <strong>.+?</strong> の検索結果 約 <strong>([\d,]+)</strong> 件};

 push( @candidate_array , { 'hyoki'            => $a_number_of_found_pages ? '（'.$a_number_of_found_pages.'件 見つかりました）' : '( ﾟ∀ﾟ)o彡゜エラー！エラー！' ,
                            'comment'          => 'はてな検索で数えてみた' ,
                            'alternative'      => '> ウェブ全体から '.$a_request_data->{composition_string}.' の検索結果 約 '.$a_number_of_found_pages.' 件' ,
                            'alternative_type' => 'definite_string' } );

 $result_data{ 'candidate' } = \@candidate_array;

 return( %result_data );
}

#################################################

1; # 重要：モジュールは必ず真と解釈される値を返さなければならない
